pub struct DescriptorData {
pub oneofs: Vec<Oneof>,
pub enums: Vec<Enum>,
pub messages: Vec<Message>,
}Expand description
A struct holding collected data from a protobuf descriptor.
This data can then be used to selectively apply attributes programmatically
through the helpers from the prost Config.
Fields
oneofs: Vec<Oneof>enums: Vec<Enum>messages: Vec<Message>Trait Implementations
Sourceimpl Default for DescriptorData
impl Default for DescriptorData
Sourcefn default() -> DescriptorData
fn default() -> DescriptorData
Returns the “default value” for a type. Read more