pub struct DescriptorDataConfig { /* private fields */ }Expand description
Configures a DescriptorData instance to gather information from a protobuf descriptor,
which can be useful to apply attributes programmatically to the target items.
You can then collect the data while also setting up the validators with the set_up_validators method.
Should you wish to not collect any data at all, you can call the omonimous function set_up_validators exported to the root, which will set up the validators and return an empty DescriptorData instance.
Implementations
Sourceimpl DescriptorDataConfig
impl DescriptorDataConfig
Sourcepub fn set_up_validators(
&self,
config: &mut Config,
files: &[impl AsRef<Path>],
include_paths: &[impl AsRef<Path>],
packages: &[&str],
) -> Result<DescriptorData, Box<dyn Error>>
pub fn set_up_validators( &self, config: &mut Config, files: &[impl AsRef<Path>], include_paths: &[impl AsRef<Path>], packages: &[&str], ) -> Result<DescriptorData, Box<dyn Error>>
Sets up the validators for the specified packages, while also collecting the data that was requested
in the configuration. Refer to the omonimous set_up_validators function’s documentation to learn more about the implementations provided by this method.
Sourcepub const fn collect_all_data() -> Self
pub const fn collect_all_data() -> Self
Collects data for all items: oneofs, enums and messages.
Sourcepub const fn collect_oneofs_data(self) -> Self
pub const fn collect_oneofs_data(self) -> Self
Toggles collection of data for oneofs.
Sourcepub const fn collect_enums_data(self) -> Self
pub const fn collect_enums_data(self) -> Self
Toggles collection of data for enums.
Sourcepub const fn collect_messages_data(self) -> Self
pub const fn collect_messages_data(self) -> Self
Toggles collection of data for messages.